# Copyright 2021 Q-CTRL. All rights reserved.
#
# Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
# copying or use of this file, via any medium, is strictly prohibited.
# Proprietary and confidential. You may not use this file except in compliance
# with the License. You may obtain a copy of the License at
#
#    https://q-ctrl.com/terms
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS. See the
# License for the specific language.

"""qctrlmloop - integration between Boulder Opal automated closed-loop optimizers and M-LOOP"""

__author__ = "Q-CTRL <support@q-ctrl.com>"
__version__ = "1.1.0"

from .controller import (
    QctrlController,
    qctrl_controller,
)

__all__ = ["QctrlController", "qctrl_controller"]
